==> pedia-3.3.0.tgz: package/compile-terms.ts <==
import fs from "fs";
import matter from "gray-matter";
import path from "path";
import { z } from "zod";

const schema = z.strictObject({
  labels: z.array(z.string()).optional(),
  relatedTerms: z.array(z.string()).optional(),
  usageInstructions: z.string().optional(),
  exampleUsage: z.string().optional(),
  businessContext: z.string().optional(),
  internalOnly: z.boolean().optional(),
  learnMore: z.string().url().optional(),
  learnMoreText: z.string().optional(),
  surroundingContextsToAvoid: z.array(z.string()).optional(),
});

export function parseMarkdown(filePath: string) {
  const fileContent = fs.readFileSync(filePath, "utf-8");

  const { data, content } = matter(fileContent);

  return {
    definition: content,
    frontmatter: schema.parse(data),
  };
}

const terms: Record<string, ReturnType<typeof parseMarkdown>> = {};

const termsPath = path.join(__dirname, "terms");

const termsFiles = fs.readdirSync(termsPath);

for (const file of termsFiles) {
  const term = parseMarkdown(path.join(termsPath, file));

  // Don't include internalOnly terms in the terms to highlight
  if (term.frontmatter.internalOnly) {
    continue;
  }

  // Append "Learn more" links to text to display
  if (term.frontmatter.learnMore) {
    term.definition += ` [${
      term.frontmatter.learnMoreText
        ? term.frontmatter.learnMoreText
        : "Learn more"
    }.](${term.frontmatter.learnMore})`;
  }

  terms[
    // decodeURIComponent is used to convert the filename back to the term name if
    // the term name includes any slashes (%2F)
    decodeURIComponent(
      // the term name is the filename without the extension
      path.basename(file, path.extname(file))
    ).toLowerCase()
  ] = term;
}

fs.writeFileSync(
  path.join(__dirname, "src", "terms.json"),
  JSON.stringify(terms)
);

==> pedia-4.1.3.tgz: package/compile-terms.ts <==
import fs from "fs";
import matter from "gray-matter";
import path from "path";
import { z } from "zod";

const schema = z.strictObject({
  labels: z.array(z.string()).optional(),
  relatedTerms: z.array(z.string()).optional(),
  usageInstructions: z.array(z.string()).optional(),
  exampleUsage: z.string().optional(),
  businessContext: z.string().optional(),
  internalOnly: z.boolean().optional(),
  learnMore: z.string().url().optional(),
  learnMoreText: z.string().optional(),
  surroundingContextsToAvoid: z.array(z.string()).optional(),
});

export function parseMarkdown(filePath: string) {
  const fileContent = fs.readFileSync(filePath, "utf-8");

  const { data, content } = matter(fileContent);

  return {
    definition: content,
    frontmatter: schema.parse(data),
  };
}

const terms: Record<string, ReturnType<typeof parseMarkdown>> = {};

const termsPath = path.join(__dirname, "terms");

const termsFiles = fs.readdirSync(termsPath);

for (const file of termsFiles) {
  const term = parseMarkdown(path.join(termsPath, file));

  // Don't include internalOnly terms in the terms to highlight
  if (term.frontmatter.internalOnly) {
    continue;
  }

  // Append "Learn more" links to text to display
  if (term.frontmatter.learnMore) {
    term.definition += ` [${
      term.frontmatter.learnMoreText
        ? term.frontmatter.learnMoreText
        : "Learn more"
    }.](${term.frontmatter.learnMore})`;
  }

  terms[
    // decodeURIComponent is used to convert the filename back to the term name if
    // the term name includes any slashes (%2F)
    decodeURIComponent(
      // the term name is the filename without the extension
      path.basename(file, path.extname(file))
    ).toLowerCase()
  ] = term;
}

fs.writeFileSync(
  path.join(__dirname, "src", "terms.json"),
  JSON.stringify(terms)
);
